pub enum EncodeError {
Io(Error),
UnsupportedMode(&'static str),
PngEncoder(EncodingError),
}Expand description
Errors that can occur during encoding.
Variants
Io(Error)
An I/O error writing to the output sink.
UnsupportedMode(&'static str)
The pixel mode is not supported by the chosen encoder.
The message describes what the caller should do instead.
PngEncoder(EncodingError)
An internal error from the png encoder (non-I/O).